summaryrefslogtreecommitdiffstats
path: root/compiler/rustc_hir_analysis/src/outlives/utils.rs
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-19 09:26:03 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-19 09:26:03 +0000
commit9918693037dce8aa4bb6f08741b6812923486c18 (patch)
tree21d2b40bec7e6a7ea664acee056eb3d08e15a1cf /compiler/rustc_hir_analysis/src/outlives/utils.rs
parentReleasing progress-linux version 1.75.0+dfsg1-5~progress7.99u1. (diff)
downloadrustc-9918693037dce8aa4bb6f08741b6812923486c18.tar.xz
rustc-9918693037dce8aa4bb6f08741b6812923486c18.zip
Merging upstream version 1.76.0+dfsg1.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'compiler/rustc_hir_analysis/src/outlives/utils.rs')
-rw-r--r--compiler/rustc_hir_analysis/src/outlives/utils.rs14
1 files changed, 9 insertions, 5 deletions
diff --git a/compiler/rustc_hir_analysis/src/outlives/utils.rs b/compiler/rustc_hir_analysis/src/outlives/utils.rs
index a6410c944..8077acea5 100644
--- a/compiler/rustc_hir_analysis/src/outlives/utils.rs
+++ b/compiler/rustc_hir_analysis/src/outlives/utils.rs
@@ -80,6 +80,10 @@ pub(crate) fn insert_outlives_predicate<'tcx>(
.or_insert(span);
}
+ Component::Placeholder(_) => {
+ span_bug!(span, "Should not deduce placeholder outlives component");
+ }
+
Component::Alias(alias_ty) => {
// This would either arise from something like:
//
@@ -146,11 +150,11 @@ fn is_free_region(region: Region<'_>) -> bool {
// These correspond to `T: 'a` relationships:
//
// struct Foo<'a, T> {
// field: &'a T, // this would generate a ReEarlyBound referencing `'a`
// }
//
// We care about these, so fall through.
- ty::ReEarlyBound(_) => true,
+ ty::ReEarlyParam(_) => true,
// These correspond to `T: 'static` relationships which can be
// rather surprising.
@@ -167,13 +171,13 @@ fn is_free_region(region: Region<'_>) -> bool {
// }
//
// The type above might generate a `T: 'b` bound, but we can
- // ignore it. We can't put it on the struct header anyway.
- ty::ReLateBound(..) => false,
+ // ignore it. We can't name this lifetime pn the struct header anyway.
+ ty::ReBound(..) => false,
ty::ReError(_) => false,
// These regions don't appear in types from type declarations:
- ty::ReErased | ty::ReVar(..) | ty::RePlaceholder(..) | ty::ReFree(..) => {
+ ty::ReErased | ty::ReVar(..) | ty::RePlaceholder(..) | ty::ReLateParam(..) => {
bug!("unexpected region in outlives inference: {:?}", region);
}
}
@@ -146,11 +150,11 @@ fn is_free_region(region: Region<'_>) -> bool {
//
// struct Foo<'a, T> {
- // field: &'a T, // this would generate a ReEarlyBound referencing `'a`
+ // field: &'a T, // this would generate a ReEarlyParam referencing `'a`
// }
//